Learn R Programming

Dykstra (version 1.0-0)

Dykstra-internal: Print Dykstra Results

Description

Prints convergence and fit information.

Usage

# S3 method for dykstra
print(x, n = 5L, ...)

Arguments

x

Object of class "dykstra" output from dykstra.

n

Does not print solutions with more than n coefficients.

Ignored.

Details

Displays the convergence flag, the final iteration count, the obtained solution, and the value of the qudratic function at the obtained solution.

Examples

Run this code
# NOT RUN {
?dykstra
# }

Run the code above in your browser using DataLab